# PyDobble

A simple console-based version of the game Dobble.

Supports any number of players, and varying levels of difficulty. 

If you have [uv](https://github.com/astral-sh/uv), you can install and run with a single command: `uvx --from pydobble dobble`

Otherwise just `pip install pydobble` and then run with `dobble`.

![](https://github.com/tech4bueno/pydobble/demo.gif)

With thanks to [rich](https://github.com/Textualize/rich) for the user interface.
